svn commit: r202242 - stable/7/sys/sparc64/sparc64

Marius Strobl marius at FreeBSD.org
Wed Jan 13 20:51:23 UTC 2010


Author: marius
Date: Wed Jan 13 20:51:23 2010
New Revision: 202242
URL: http://svn.freebsd.org/changeset/base/202242

Log:
  MFC: r200915
  
  Don't probe the bq4802 variant found in Ultra 25 and 45 for now as
  this chip isn't MC146818 compatible and requires different handlers
  (but which I can't test due to lack of such hardware).

Modified:
  stable/7/sys/sparc64/sparc64/rtc.c
Directory Properties:
  stable/7/sys/   (props changed)
  stable/7/sys/cddl/contrib/opensolaris/   (props changed)
  stable/7/sys/contrib/dev/acpica/   (props changed)
  stable/7/sys/contrib/pf/   (props changed)

Modified: stable/7/sys/sparc64/sparc64/rtc.c
==============================================================================
--- stable/7/sys/sparc64/sparc64/rtc.c	Wed Jan 13 20:51:21 2010	(r202241)
+++ stable/7/sys/sparc64/sparc64/rtc.c	Wed Jan 13 20:51:23 2010	(r202242)
@@ -28,10 +28,11 @@
 __FBSDID("$FreeBSD$");
 
 /*
  * The `rtc' device is a MC146818 compatible clock found on the ISA
  * bus and EBus. The EBus variant actually is the Real-Time Clock
  * function of a National Semiconductor PC87317/PC97317 which also
  * provides Advanced Power Control functionality.
  */
 
 #include "opt_isa.h"
@@ -130,6 +131,10 @@ rtc_ebus_probe(device_t dev)
 {
 
 	if (strcmp(ofw_bus_get_name(dev), "rtc") == 0) {
+		/* The bq4802 is not supported, yet. */
+		if (ofw_bus_get_compat(dev) != NULL &&
+		    strcmp(ofw_bus_get_compat(dev), "bq4802") == 0)
+			return (ENXIO);
 		device_set_desc(dev, RTC_DESC);
 		return (0);
 	}
@@ -28,10 +28,11 @@
 
 /*
- * The `rtc' device is a MC146818 compatible clock found on the ISA
- * bus and EBus. The EBus variant actually is the Real-Time Clock
- * function of a National Semiconductor PC87317/PC97317 which also
- * provides Advanced Power Control functionality.
+ * The `rtc' device is found on the ISA bus and the EBus.  The ISA version
+ * always is a MC146818 compatible clock while the EBus variant either is the
+ * MC146818 compatible Real-Time Clock function of a National Semiconductor
+ * PC87317/PC97317 which also provides Advanced Power Control functionality
+ * or a Texas Instruments bq4802.
  */
 


More information about the svn-src-stable-7 mailing list